===================
Author and Credits
===================

Author
------
* Gianluca Gippetto <gianluca.gippetto@gmail.com>

Credits
-------

- For implementing option groups, I started from the idea of
  `@chrisjsewell <https://github.com/chrisjsewell>`_
  presented in `this comment <https://github.com/pallets/click/issues/373#issuecomment-515293746>`_.

- This package was bootstrapped with Cookiecutter_ and the
  `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/cookiecutter/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyfeldroy/cookiecutter-pypackage
